@@ -135,7 +135,7 @@ def initialize(device, scsi_id, drive_speed, media_type):
       
       - **device** : Filesystem device name (i.e. '/dev/cdrw')
 
-      - **scsi_id** : SCSI id for the device (i.e. '[devicename, scsibus, lun]')
+      - **scsi_id** : SCSI id for the device, in the form '[ATA:]scsibus,target,lun'
 
       - **drive_speed** : Speed at which drive writes (i.e. '2' for 2x drive, etc.)
 
@@ -201,29 +201,13 @@ def initialize(device, scsi_id, drive_speed, media_type):
       # Validate the scsi_id argument
       ################################
 
-      if len(scsi_id) < 3:
-         errors.append("Error: SCSI id '%s' invalid; must be in the form [scsibus,target,lun].\n" % scsi_id)
+      ata_scsi_id_pattern = re.compile(r"^\s*ATA:[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*$")
+      scsi_id_pattern = re.compile(r"^\s*[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*$")
+      if not ata_scsi_id_pattern.search(scsi_id) and not scsi_id_pattern.search(scsi_id):
+         errors.append("Error: SCSI id '%s' invalid; must be in the form '[ATA:]scsibus,target,lun'.\n" % scsi_id)
          raise CedarBackupError()
 
-      try:
-         device_dict['devicename']  = int(scsi_id[0])
-         device_dict['scsibus']     = int(scsi_id[1])
-         device_dict['lun']         = int(scsi_id[2])
-      except:
-         errors.append("Error: SCSI devicename,scsibus,lun (%s) must be integers." % scsi_id);
-         raise CedarBackupError()
-
-      if device_dict['devicename'] < 0:
-         errors.append("Error: SCSI devicename '%d' invalid; value must be >= 0.\n" % device_dict['devicename'])
-         raise CedarBackupError()
-
-      if device_dict['scsibus'] < 0:
-         errors.append("Error: SCSI scsibus value '%d' invalid; must be >= 0.\n" % device_dict['scsibus'])
-         raise CedarBackupError()
-
-      if device_dict['lun'] < 0:
-         errors.append("Error: lun value '%s' invalid; must be >= 0.\n" % device_dict['lun'])
-         raise CedarBackupError()
+      device_dict['scsi_id'] = scsi_id
 
 
       ######################
@@ -296,8 +280,7 @@ def initialize(device, scsi_id, drive_speed, media_type):
       device_dict['eject']       = False
 
       # Get the properties
-      properties_cmd = "%s -prcap -dev %d,%d,%d" % (CDRECORD_PROGRAM, device_dict['devicename'], 
-                                                    device_dict['scsibus'], device_dict['lun'])
+      properties_cmd = "%s -prcap dev=%s" % (CDRECORD_PROGRAM, device_dict['scsi_id'])
       (result, lines) = execute_command(properties_cmd)
       if result != 0:
          errors.append("Error: unable to check properties on device.  Effective user may be improper.\n")
@@ -431,8 +414,8 @@ def capacity(device_dict, new=False):
 
    else:
       boundary_pattern = re.compile(r"(^)([0-9]*)(,)([0-9]*)($)")
-      boundary_cmd = "%s -msinfo -dev=%d,%d,%d" % (CDRECORD_PROGRAM, device_dict['devicename'],
-                                                   device_dict['scsibus'], device_dict['lun'])
+
+      boundary_cmd = "%s -msinfo dev=%s" % (CDRECORD_PROGRAM, device_dict['scsi_id'])
       (result, lines) = execute_command(boundary_cmd)
       if result != 0:
          return None
@@ -573,11 +556,11 @@ def create_image(iso_image, device_dict, dir_list, boundaries=[]):
       #################
 
       # Trailing '/' characters will slightly mess up the resulting tree
-      for dir in dir_list:
-         if dir['prefix'][len(dir['prefix'])-1] == '/':
-            dir['prefix'] = dir['prefix'][0:-1]
-         if dir['source_dir'][len(dir['source_dir'])-1] == '/':
-            dir['source_dir'] = dir['source_dir'][0:-1]
+      for d in dir_list:
+         if d['prefix'][len(d['prefix'])-1] == '/':
+            d['prefix'] = d['prefix'][0:-1]
+         if d['source_dir'][len(d['source_dir'])-1] == '/':
+            d['source_dir'] = d['source_dir'][0:-1]
 
 
       ####################
@@ -585,8 +568,8 @@ def create_image(iso_image, device_dict, dir_list, boundaries=[]):
       ####################
 
       dir_string = ""
-      for dir in dir_list:
-         dir_string += "%s/=%s/ " % (dir['prefix'], dir['source_dir'])
+      for d in dir_list:
+         dir_string += "%s/=%s/ " % (d['prefix'], d['source_dir'])
 
       if boundaries:
          mkisofs_cmd = "%s -graft-points -r -o %s -C %d,%d -M %s %s" % (
@@ -716,7 +699,7 @@ def write_image(iso_image, device_dict, new=False, multi=True):
             blank_cmd  = "%s -v" % CDRECORD_PROGRAM
             blank_cmd += " blank=fast"
             blank_cmd += " speed=%s" % (device_dict['drive_speed'])
-            blank_cmd += " dev=%d,%d,%d" % (device_dict['devicename'], device_dict['scsibus'], device_dict['lun'])
+            blank_cmd += " dev=%s" % (device_dict['scsi_id'])
 
             _eject(device_dict)
 
@@ -741,7 +724,7 @@ def write_image(iso_image, device_dict, new=False, multi=True):
          write_cmd  = "%s -v" % CDRECORD_PROGRAM
 
          write_cmd += " speed=%s" % (device_dict['drive_speed'])
-         write_cmd += " dev=%d,%d,%d" % (device_dict['devicename'], device_dict['scsibus'], device_dict['lun'])
+         write_cmd += " dev=%s" % (device_dict['scsi_id'])
 
          if multi and device_dict['multi']:
             write_cmd += " -multi"
