@@ -339,7 +339,7 @@ def _read_reference(dom):
    results['errors']   = None
    results['warnings'] = None
 
-   dict                = { }
+   dictx               = { }
    errors              = [ ]
    warnings            = [ ]
 
@@ -359,9 +359,9 @@ def _read_reference(dom):
    # Read values from the file
    ############################
 
-   dict['author']        = Evaluate('string(//cb_config/reference/author)', dom.documentElement)
-   dict['revision']      = Evaluate('string(//cb_config/reference/revision)', dom.documentElement)
-   dict['description']   = Evaluate('string(//cb_config/reference/description)', dom.documentElement)
+   dictx['author']        = Evaluate('string(//cb_config/reference/author)', dom.documentElement)
+   dictx['revision']      = Evaluate('string(//cb_config/reference/revision)', dom.documentElement)
+   dictx['description']   = Evaluate('string(//cb_config/reference/description)', dom.documentElement)
 
 
    #####################
@@ -371,7 +371,7 @@ def _read_reference(dom):
    if len(errors) > 0:
       results['errors'] = errors
    else:
-      results['dict'] = dict
+      results['dict'] = dictx
 
    if len(warnings) > 0:
       results['warnings'] = warnings
@@ -433,7 +433,7 @@ def _read_options(dom):
    results['errors']   = None
    results['warnings'] = None
 
-   dict                = { }
+   dictx               = { }
    errors              = [ ]
    warnings            = [ ]
 
@@ -459,44 +459,44 @@ def _read_options(dom):
       # Read values from the file
       ############################
 
-      dict['starting_day']  = Evaluate('string(//cb_config/options/starting_day)', dom.documentElement)
-      dict['working_dir']   = Evaluate('string(//cb_config/options/working_dir)', dom.documentElement)
-      dict['backup_user']   = Evaluate('string(//cb_config/options/backup_user)', dom.documentElement)
-      dict['backup_group']  = Evaluate('string(//cb_config/options/backup_group)', dom.documentElement)
-      dict['rcp_command']   = Evaluate('string(//cb_config/options/rcp_command)', dom.documentElement)
+      dictx['starting_day']  = Evaluate('string(//cb_config/options/starting_day)', dom.documentElement)
+      dictx['working_dir']   = Evaluate('string(//cb_config/options/working_dir)', dom.documentElement)
+      dictx['backup_user']   = Evaluate('string(//cb_config/options/backup_user)', dom.documentElement)
+      dictx['backup_group']  = Evaluate('string(//cb_config/options/backup_group)', dom.documentElement)
+      dictx['rcp_command']   = Evaluate('string(//cb_config/options/rcp_command)', dom.documentElement)
 
 
       #############################
       # Validate the configuration
       #############################
 
-      if dict['starting_day'] not in ['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday' ]:
+      if dictx['starting_day'] not in ['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday' ]:
          errors.append("Error: starting day '%s' invalid; must be valid weekday name (i.e. 'sunday', etc.)\n" 
-                        % dict['starting_day'])
+                        % dictx['starting_day'])
          raise CedarBackupError()
 
-      if not os.path.isabs(dict['working_dir']):
+      if not os.path.isabs(dictx['working_dir']):
          errors.append("Error: working directory '%s' invalid; must be specified as an absolute path.\n" 
-                        % dict['working_dir'])
+                        % dictx['working_dir'])
          raise CedarBackupError()
 
-      if not os.path.isdir(dict['working_dir']) or not os.access(dict['working_dir'], os.W_OK):
+      if not os.path.isdir(dictx['working_dir']) or not os.access(dictx['working_dir'], os.W_OK):
          errors.append("Error: working directory '%s' invalid; does not appear be writable by effective user.\n"
-                        % dict['working_dir'])
+                        % dictx['working_dir'])
          raise CedarBackupError()
 
-      id_command = "%s %s" % (GROUP_PROGRAM, dict['backup_user'])
+      id_command = "%s %s" % (GROUP_PROGRAM, dictx['backup_user'])
       (result, lines) = execute_command(id_command)
       if result != 0:
-         errors.append("Error: backup user '%s' invalid; does not appear to exist.\n" % dict['backup_user'])
+         errors.append("Error: backup user '%s' invalid; does not appear to exist.\n" % dictx['backup_user'])
          raise CedarBackupError()
 
-      if dict['backup_group'] not in string.split(lines[0][string.find(lines[0], ":")+1:]):
+      if dictx['backup_group'] not in string.split(lines[0][string.find(lines[0], ":")+1:]):
          errors.append("Error: backup group '%s' invalid; not in '%s' user's groupset.\n" 
-                       % (dict['backup_group'],dict['backup_user']))
+                       % (dictx['backup_group'],dictx['backup_user']))
          raise CedarBackupError()
       
-      program = string.split(dict['rcp_command'])[0]
+      program = string.split(dictx['rcp_command'])[0]
       if not os.path.isabs(program):
          errors.append("Error: invalid rcp command '%s'; must be specified as an absolute path.\n" % program)
          raise CedarBackupError()
@@ -520,7 +520,7 @@ def _read_options(dom):
    if len(errors) > 0:
       results['errors'] = errors
    else:
-      results['dict'] = dict
+      results['dict'] = dictx
 
    if len(warnings) > 0:
       results['warnings'] = warnings
@@ -583,7 +583,7 @@ def _read_collect(dom):
    results['errors']   = None
    results['warnings'] = None
 
-   dict                = { }
+   dictx               = { }
    errors              = [ ]
    warnings            = [ ]
 
@@ -609,21 +609,21 @@ def _read_collect(dom):
       # Read values from the file
       ############################
 
-      dict['collect_dir']  = Evaluate('string(//cb_config/collect/collect_dir)', dom.documentElement)
-      dict['archive_mode'] = Evaluate('string(//cb_config/collect/archive_mode)', dom.documentElement)
-      dict['ignore_file'] = Evaluate('string(//cb_config/collect/ignore_file)', dom.documentElement)
+      dictx['collect_dir']  = Evaluate('string(//cb_config/collect/collect_dir)', dom.documentElement)
+      dictx['archive_mode'] = Evaluate('string(//cb_config/collect/archive_mode)', dom.documentElement)
+      dictx['ignore_file'] = Evaluate('string(//cb_config/collect/ignore_file)', dom.documentElement)
 
       i = 0
-      dict['dir'] = [ ]
+      dictx['dir'] = [ ]
       while Evaluate('//cb_config/collect/dir[%d]' % (i+1), dom.documentElement) != []:
-         dict['dir'].append({ })
-         dict['dir'][i]['abs_path'] = Evaluate('string(//cb_config/collect/dir[%d]/abs_path)' % (i+1), dom.documentElement)
-         dict['dir'][i]['mode'] = Evaluate('string(//cb_config/collect/dir[%d]/mode)' % (i+1), dom.documentElement)
+         dictx['dir'].append({ })
+         dictx['dir'][i]['abs_path'] = Evaluate('string(//cb_config/collect/dir[%d]/abs_path)' % (i+1), dom.documentElement)
+         dictx['dir'][i]['mode'] = Evaluate('string(//cb_config/collect/dir[%d]/mode)' % (i+1), dom.documentElement)
 
          j = 0
-         dict['dir'][i]['exclude'] = [ ]
+         dictx['dir'][i]['exclude'] = [ ]
          while Evaluate('//cb_config/collect/dir[%d]/exclude/abs_path[%d]' % (i+1, j+1), dom.documentElement) != []:
-            dict['dir'][i]['exclude'].append(Evaluate('string(//cb_config/collect/dir[%d]/exclude/abs_path[%d])' % 
+            dictx['dir'][i]['exclude'].append(Evaluate('string(//cb_config/collect/dir[%d]/exclude/abs_path[%d])' % 
                                              (i+1, j+1), dom.documentElement))
             j += 1
 
@@ -634,29 +634,29 @@ def _read_collect(dom):
       # Validate the configuration
       #############################
 
-      if not os.path.isabs(dict['collect_dir']):
-         errors.append("Error: collect directory '%s' invalid; must be specified as an absolute path.\n" % dict['collect_dir'])
+      if not os.path.isabs(dictx['collect_dir']):
+         errors.append("Error: collect directory '%s' invalid; must be specified as an absolute path.\n" % dictx['collect_dir'])
          raise CedarBackupError()
 
-      if not os.path.isdir(dict['collect_dir']) or not os.access(dict['collect_dir'], os.W_OK):
+      if not os.path.isdir(dictx['collect_dir']) or not os.access(dictx['collect_dir'], os.W_OK):
          errors.append("Error: collect directory '%s' invalid; does not appear be writable by effective user.\n" 
-                        % dict['collect_dir'])
+                        % dictx['collect_dir'])
          raise CedarBackupError()
 
-      if dict['archive_mode'] not in ['tar', 'targz', 'tarbz2', 'tarz']:
+      if dictx['archive_mode'] not in ['tar', 'targz', 'tarbz2', 'tarz']:
          errors.append("Error: archive mode '%s' invalid; must be one of [tar, targz, tarbz2, tarz]\n" 
-                        % dict['archive_mode'])
+                        % dictx['archive_mode'])
          raise CedarBackupError()
 
-      for dir in dict['dir']:
-         if not os.path.isabs(dir['abs_path']):
-            errors.append("Error: directory path '%s' invalid; must be specified as an absolute path.\n" % dir['abs_path'])
+      for d in dictx['dir']:
+         if not os.path.isabs(d['abs_path']):
+            errors.append("Error: directory path '%s' invalid; must be specified as an absolute path.\n" % d['abs_path'])
             raise CedarBackupError()
-         if dir['mode'] not in ['daily', 'weekly', 'incr']:
-            errors.append("Error: archive mode '%s' invalid; must be one of [daily, weekly, incr]\n" % dir['mode'])
+         if d['mode'] not in ['daily', 'weekly', 'incr']:
+            errors.append("Error: archive mode '%s' invalid; must be one of [daily, weekly, incr]\n" % d['mode'])
             raise CedarBackupError()
 
-         for path in dir['exclude']:
+         for path in d['exclude']:
             if not os.path.isabs(path):
                errors.append("Error: exclude path '%s' invalid; must be specified as an absolute path.\n" % path)
                raise CedarBackupError()
@@ -677,7 +677,7 @@ def _read_collect(dom):
    if len(errors) > 0:
       results['errors'] = errors
    else:
-      results['dict'] = dict
+      results['dict'] = dictx
 
    if len(warnings) > 0:
       results['warnings'] = warnings
@@ -738,7 +738,7 @@ def _read_stage(dom):
    results['errors']   = None
    results['warnings'] = None
 
-   dict                = { }
+   dictx               = { }
    errors              = [ ]
    warnings            = [ ]
 
@@ -764,16 +764,16 @@ def _read_stage(dom):
       # Read values from the file
       ############################
 
-      dict['staging_dir']  = Evaluate('string(//cb_config/stage/staging_dir)', dom.documentElement)
+      dictx['staging_dir']  = Evaluate('string(//cb_config/stage/staging_dir)', dom.documentElement)
 
       i = 0
-      dict['peer'] = [ ]
+      dictx['peer'] = [ ]
       while Evaluate('//cb_config/stage/peer[%d]' % (i+1), dom.documentElement) != []:
-         dict['peer'].append({ })
-         dict['peer'][i]['name'] = Evaluate('string(//cb_config/stage/peer[%d]/name)' % (i+1), dom.documentElement)
-         dict['peer'][i]['type'] = Evaluate('string(//cb_config/stage/peer[%d]/type)' % (i+1), dom.documentElement)
-         dict['peer'][i]['collect_dir'] = Evaluate('string(//cb_config/stage/peer[%d]/collect_dir)' % (i+1), dom.documentElement)
-         dict['peer'][i]['backup_user'] = Evaluate('string(//cb_config/stage/peer[%d]/backup_user)' % (i+1), dom.documentElement)
+         dictx['peer'].append({ })
+         dictx['peer'][i]['name'] = Evaluate('string(//cb_config/stage/peer[%d]/name)' % (i+1), dom.documentElement)
+         dictx['peer'][i]['type'] = Evaluate('string(//cb_config/stage/peer[%d]/type)' % (i+1), dom.documentElement)
+         dictx['peer'][i]['collect_dir'] = Evaluate('string(//cb_config/stage/peer[%d]/collect_dir)' % (i+1), dom.documentElement)
+         dictx['peer'][i]['backup_user'] = Evaluate('string(//cb_config/stage/peer[%d]/backup_user)' % (i+1), dom.documentElement)
          i += 1
 
 
@@ -781,16 +781,16 @@ def _read_stage(dom):
       # Validate the configuration
       #############################
 
-      if not os.path.isabs(dict['staging_dir']):
-         errors.append("Error: staging directory '%s' invalid; must be specified as an absolute path.\n" % dict['staging_dir'])
+      if not os.path.isabs(dictx['staging_dir']):
+         errors.append("Error: staging directory '%s' invalid; must be specified as an absolute path.\n" % dictx['staging_dir'])
          raise CedarBackupError()
 
-      if not os.path.isdir(dict['staging_dir']) or not os.access(dict['staging_dir'], os.W_OK):
+      if not os.path.isdir(dictx['staging_dir']) or not os.access(dictx['staging_dir'], os.W_OK):
          errors.append("Error: staging directory '%s' invalid; does not appear be writable by effective user.\n" 
-                        % dict['staging_dir'])
+                        % dictx['staging_dir'])
          raise CedarBackupError()
 
-      for peer in dict['peer']:
+      for peer in dictx['peer']:
          if peer['type'] not in ['local', 'remote']:
             errors.append("Error: peer type '%s' invalid; must be one of [local, remote].\n" % peer['type'])
             raise CedarBackupError()
@@ -818,7 +818,7 @@ def _read_stage(dom):
    if len(errors) > 0:
       results['errors'] = errors
    else:
-      results['dict'] = dict
+      results['dict'] = dictx
 
    if len(warnings) > 0:
       results['warnings'] = warnings
@@ -836,7 +836,7 @@ def _read_stage(dom):
 #  -----------------------------------------------------------------------------------------------------------------------------
 #  dict['source_dir']                        source_dir                    Directory from which to create the ISO image.
 #  dict['target_device']                     target_device                 System backup device (i.e. /dev/cdrw).
-#  dict['target_scsi_id']                    target_scsi_id                SCSI ID for backup device in form (scsibus,target,lun)
+#  dict['target_scsi_id']                    target_scsi_id                SCSI ID for device in form '[ATA:]scsibus,target,lun'
 #  dict['drive_speed']                       drive_speed                   Drive speed (i.e. 2 for 2x CD-R, 4 for 4x CD-R, etc.).
 #  dict['media_type']                        media_type                    Media type.  One of [cdrw-74, cdr-74].
 #  dict['check_data']                        check_data                    Run consistency check?  Must be one of [Y,N].
@@ -880,7 +880,7 @@ def _read_store(dom):
    results['errors']   = None
    results['warnings'] = None
 
-   dict                = { }
+   dictx               = { }
    errors              = [ ]
    warnings            = [ ]
 
@@ -906,11 +906,11 @@ def _read_store(dom):
       # Read values from the file
       ############################
 
-      dict['source_dir']      = Evaluate('string(//cb_config/store/source_dir)', dom.documentElement)
-      dict['target_device']   = Evaluate('string(//cb_config/store/target_device)', dom.documentElement)
+      dictx['source_dir']      = Evaluate('string(//cb_config/store/source_dir)', dom.documentElement)
+      dictx['target_device']   = Evaluate('string(//cb_config/store/target_device)', dom.documentElement)
       target_scsi_id          = Evaluate('string(//cb_config/store/target_scsi_id)', dom.documentElement)
       drive_speed             = Evaluate('string(//cb_config/store/drive_speed)', dom.documentElement)
-      dict['media_type']      = Evaluate('string(//cb_config/store/media_type)', dom.documentElement)
+      dictx['media_type']      = Evaluate('string(//cb_config/store/media_type)', dom.documentElement)
       temp_check_data         = string.upper(Evaluate('string(//cb_config/store/check_data)', dom.documentElement))
 
 
@@ -918,55 +918,54 @@ def _read_store(dom):
       # Validate the configuration
       #############################
 
-      if not os.path.isabs(dict['source_dir']):
-         errors.append("Error: source directory '%s' invalid; must be specified as an absolute path.\n" % dict['source_dir'])
+      if not os.path.isabs(dictx['source_dir']):
+         errors.append("Error: source directory '%s' invalid; must be specified as an absolute path.\n" % dictx['source_dir'])
          raise CedarBackupError()
 
-      if not os.path.isabs(dict['target_device']):
-         errors.append("Error: target device '%s' invalid; must be specified as an absolute path.\n" % dict['target_device'])
+      if not os.path.isabs(dictx['target_device']):
+         errors.append("Error: target device '%s' invalid; must be specified as an absolute path.\n" % dictx['target_device'])
          raise CedarBackupError()
 
-      if os.path.islink(dict['target_device']):
+      if os.path.islink(dictx['target_device']):
          warnings.append("Warning: target device '%s' is a link; some safeguards may not catch problems.\n" 
-                         % dict['target_device'])
+                         % dictx['target_device'])
          results['warnings'] = warnings
 
-      if not os.access(dict['target_device'], os.W_OK):
+      if not os.access(dictx['target_device'], os.W_OK):
          errors.append("Error: target device '%s' invalid; does not appear be writable by effective user.\n" 
-                        % dict['target_device'])
+                        % dictx['target_device'])
          raise CedarBackupError()
 
+      ata_scsi_id_pattern = re.compile(r"^\s*ATA:[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*$")
       scsi_id_pattern = re.compile(r"^\s*[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*$")
-      if not scsi_id_pattern.search(target_scsi_id):
-         errors.append("Error: SCSI id '%s' invalid; must be in the form 'scsibus,target,lun'.\n" % target_scsi_id)
+      if not ata_scsi_id_pattern.search(target_scsi_id) and not scsi_id_pattern.search(target_scsi_id):
+         errors.append("Error: SCSI id '%s' invalid; must be in the form '[ATA:]scsibus,target,lun'.\n" % target_scsi_id)
          raise CedarBackupError()
 
-      dict['target_scsi_id'] = [ ]
-      for i in string.split(target_scsi_id, ","):
-         dict['target_scsi_id'].append(string.strip(i))
+      dictx['target_scsi_id'] = string.strip(target_scsi_id);
 
       try:
-         dict['drive_speed'] = int(drive_speed)
+         dictx['drive_speed'] = int(drive_speed)
       except ValueError:
          errors.append("Error: drive speed '%s' invalid; must be an integer >= 1.\n" % drive_speed)
          raise CedarBackupError()
 
-      if dict['drive_speed'] < 1:
-         errors.append("Error: drive speed '%d' invalid; must be an integer >= 1.\n" % dict['drive_speed'])
+      if dictx['drive_speed'] < 1:
+         errors.append("Error: drive speed '%d' invalid; must be an integer >= 1.\n" % dictx['drive_speed'])
          raise CedarBackupError()
 
-      if dict['media_type'] not in ['cdr-74', 'cdrw-74']:
-         errors.append("Error: media type '%s' invalid; must be one of [cdr-74, cdrw-74].\n" % dict['media_type'])
+      if dictx['media_type'] not in ['cdr-74', 'cdrw-74']:
+         errors.append("Error: media type '%s' invalid; must be one of [cdr-74, cdrw-74].\n" % dictx['media_type'])
          raise CedarBackupError()
 
       if temp_check_data not in ['Y', 'N']:
-         errors.append("Error: check-data Y/N value '%s' invalid.\n" % dict['check_data'])
+         errors.append("Error: check-data Y/N value '%s' invalid.\n" % dictx['check_data'])
          raise CedarBackupError()
 
       if temp_check_data == "Y":
-         dict['check_data'] = True
+         dictx['check_data'] = True
       else:
-         dict['check_data'] = False
+         dictx['check_data'] = False
       
 
    #####################################
@@ -984,7 +983,7 @@ def _read_store(dom):
    if len(errors) > 0:
       results['errors'] = errors
    else:
-      results['dict'] = dict
+      results['dict'] = dictx
 
    if len(warnings) > 0:
       results['warnings'] = warnings
@@ -1039,7 +1038,7 @@ def _read_purge(dom):
    results['errors']   = None
    results['warnings'] = None
 
-   dict                = { }
+   dictx               = { }
    errors              = [ ]
    warnings            = [ ]
 
@@ -1068,10 +1067,10 @@ def _read_purge(dom):
       ############################
 
       i = 0
-      dict['dir'] = [ ]
+      dictx['dir'] = [ ]
       while Evaluate('//cb_config/purge/dir[%d]' % (i+1), dom.documentElement) != []:
-         dict['dir'].append({ })
-         dict['dir'][i]['abs_path'] = Evaluate('string(//cb_config/purge/dir[%d]/abs_path)' % (i+1), dom.documentElement)
+         dictx['dir'].append({ })
+         dictx['dir'][i]['abs_path'] = Evaluate('string(//cb_config/purge/dir[%d]/abs_path)' % (i+1), dom.documentElement)
          retain_days.append(Evaluate('string(//cb_config/purge/dir[%d]/retain_days)' % (i+1), dom.documentElement))
          i += 1
 
@@ -1081,19 +1080,19 @@ def _read_purge(dom):
       #############################
 
       i = 0
-      for dir in dict['dir']:
-         if not os.path.isabs(dir['abs_path']):
-            errors.append("Error: purge directory '%s' invalid; must be specified as an absolute path.\n" % dir['abs_path'])
+      for d in dictx['dir']:
+         if not os.path.isabs(d['abs_path']):
+            errors.append("Error: purge directory '%s' invalid; must be specified as an absolute path.\n" % d['abs_path'])
             raise CedarBackupError()
 
          try:
-            dir['retain_days'] = float(retain_days[i])
+            d['retain_days'] = float(retain_days[i])
          except ValueError:
             errors.append("Error: retain days '%s' invalid; must be number >= 0.0.\n" % retain_days[i])
             raise CedarBackupError()
 
-         if dir['retain_days'] < 0:
-            errors.append("Error: retain days '%f' invalid; must be number >= 0.0.\n" % dir['retain_days'])
+         if d['retain_days'] < 0:
+            errors.append("Error: retain days '%f' invalid; must be number >= 0.0.\n" % d['retain_days'])
             raise CedarBackupError()
 
          i += 1
@@ -1114,7 +1113,7 @@ def _read_purge(dom):
    if len(errors) > 0:
       results['errors'] = errors
    else:
-      results['dict'] = dict
+      results['dict'] = dictx
 
    if len(warnings) > 0:
       results['warnings'] = warnings
