@@ -1259,17 +1259,17 @@ def consistency_check(working_dir, device, source_dir, date_list):
             # This might get a bit inefficient if the trees are big.
 
             disc_list = []
-            list = expand_tree(disc_dir)
-            for file in list:
-               if file != disc_dir and os.path.isfile(file) and not os.path.islink(file):
-                  disc_list.append(string.replace(file, "%s/" % disc_dir, "", 1))
+            lst = expand_tree(disc_dir)
+            for f in lst:
+               if f != disc_dir and os.path.isfile(f) and not os.path.islink(f):
+                  disc_list.append(string.replace(f, "%s/" % disc_dir, "", 1))
             disc_list.sort()
 
             daily_list = []
-            list = expand_tree(daily_dir)
-            for file in list:
-               if file != daily_dir and os.path.isfile(file) and not os.path.islink(file):
-                  daily_list.append(string.replace(file, "%s/" % daily_dir, "", 1))
+            lst = expand_tree(daily_dir)
+            for f in lst:
+               if f != daily_dir and os.path.isfile(f) and not os.path.islink(f):
+                  daily_list.append(string.replace(f, "%s/" % daily_dir, "", 1))
             daily_list.sort()
 
             if disc_list != daily_list:
@@ -1283,11 +1283,11 @@ def consistency_check(working_dir, device, source_dir, date_list):
             ##########################################
             # Note that we can use whichever list we want as the basis for our search.  
 
-            for file in disc_list:
-               disc_file = os.path.join(disc_dir, file)
-               daily_file = os.path.join(daily_dir, file)
+            for f in disc_list:
+               disc_file = os.path.join(disc_dir, f)
+               daily_file = os.path.join(daily_dir, f)
                if _file_digest(disc_file) != _file_digest(daily_file):
-                  errors.append("File '%s' differs.\n" % os.path.join(date, file))
+                  errors.append("File '%s' differs.\n" % os.path.join(date, f))
                   difference = True
 
          if not difference:
