@@ -161,27 +161,27 @@ def run_collect(config, full=False):
       # Loop for each collect directory
       ##################################
 
-      for dir in config['collect']['dir']:
+      for d in config['collect']['dir']:
 
          #############################################
          # Decide whether to deal with this directory
          #############################################
          # We always do daily/incremental, but only do weekly at the start of a week.
 
-         if (full or dir['mode'] == 'daily' or dir['mode'] == 'incr' or
-              (dir['mode'] == 'weekly' and _today_is_start(config['options']['starting_day'])) ):
+         if (full or d['mode'] == 'daily' or d['mode'] == 'incr' or
+              (d['mode'] == 'weekly' and _today_is_start(config['options']['starting_day'])) ):
 
             ##################
             # Build filenames
             ##################
 
             # Yup, we assume a UNIX-style path
-            basename = dir['abs_path']
+            basename = d['abs_path']
             basename = re.sub("^\/", "", basename)
             basename = re.sub("\/", "-", basename)
             basename = re.sub("\s", "_", basename)
 
-            if dir['mode'] == "incr" and not full:
+            if d['mode'] == "incr" and not full:
                digest_file = os.path.join(config['options']['working_dir'], "%s.sha" % basename)
             else:
                digest_file = None
@@ -200,14 +200,14 @@ def run_collect(config, full=False):
             # Create the tarfile
             #####################
 
-            call = filesystem.tar_tree(dir=dir['abs_path'], 
+            call = filesystem.tar_tree(dir=d['abs_path'], 
                                        tarfile=tarfile, 
                                        working_dir=config['options']['working_dir'], 
                                        method=config['collect']['archive_mode'],
                                        digest_file=digest_file, 
                                        reset_digest=reset_digest,
                                        ignore_file=config['collect']['ignore_file'],
-                                       exclude_list=dir['exclude'],
+                                       exclude_list=d['exclude'],
                                        user=config['options']['backup_user'],
                                        group=config['options']['backup_group'])
 
@@ -731,21 +731,21 @@ def run_purge(config):
       file_count = 0
       dir_count = 0
       for purge_dir in config['purge']['dir']:
-         for file in filesystem.aged_files(purge_dir['abs_path'], purge_dir['retain_days']):
+         for f in filesystem.aged_files(purge_dir['abs_path'], purge_dir['retain_days']):
             try:
-               os.remove(file)
+               os.remove(f)
                file_count += 1
-               output.append("Removed old file %s.\n" % file)
+               output.append("Removed old file %s.\n" % f)
             except:
-               errors.append("Error: unable to remove old file '%s'.\n" % file)
-         for dir in filesystem.empty_dirs(purge_dir['abs_path']):
+               errors.append("Error: unable to remove old file '%s'.\n" % f)
+         for d in filesystem.empty_dirs(purge_dir['abs_path']):
             try:
-               if dir != purge_dir['abs_path']:
-                  os.rmdir(dir)
+               if d != purge_dir['abs_path']:
+                  os.rmdir(d)
                   dir_count += 1
-                  output.append("Removed empty directory %s.\n" % dir)
+                  output.append("Removed empty directory %s.\n" % d)
             except:
-               errors.append("Error: unable to remove empty directory '%s'.\n" % dir)
+               errors.append("Error: unable to remove empty directory '%s'.\n" % d)
 
       output.append("Removed %d old files and %d empty directories.\n" % (file_count, dir_count))
 
@@ -883,10 +883,10 @@ def run_rebuild(config):
          overall['bytes']  = 0
          overall['mbytes'] = 0
 
-         for dir in dir_list:
-            required = filesystem.tree_size(dir['source_dir'])
+         for d in dir_list:
+            required = filesystem.tree_size(d['source_dir'])
             if required is None:
-               errors.append("Error: unable to get directory size for '%s'.\n" % dir['source_dir'])
+               errors.append("Error: unable to get directory size for '%s'.\n" % d['source_dir'])
                raise CedarBackupError()
             overall['bytes'] += required['bytes']
             overall['mbytes'] += required['mbytes']
